<?php

/*
 * LMS version 1.10.2 Roham
 *
 *  (C) Copyright 2001-2007 LMS Developers
 *
 *  Please, see the doc/AUTHORS for more information about authors!
 *
 *  This program is free software; you can redistribute it and/or modify
 *  it under the terms of the GNU General Public License Version 2 as
 *  published by the Free Software Foundation.
 *
 *  This program is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU General Public License for more details.
 *
 *  You should have received a copy of the GNU General Public License
 *  along with this program; if not, write to the Free Software
 *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307,
 *  USA.
 *
 *  $Id: postgres.2004090800.php,v 1.9.2.1 2007/08/17 13:15:18 alec Exp $
 */

$DB->BeginTrans();
$DB->Execute("
    ALTER TABLE users ADD COLUMN pin integer;
    UPDATE users SET pin=random()*10 + random()*100 + random()*1000 + random()*10000 + random()*100000-1;
    ALTER TABLE users ALTER pin SET DEFAULT 0;
    ALTER TABLE users ALTER pin SET NOT NULL;
    
    UPDATE dbinfo SET keyvalue = '2004090800' WHERE keytype = 'dbversion';
");
$DB->CommitTrans();

?>
